<template>
    <div class="monitor-page">
        <div class="container" v-if="!toFullScreen">
            <!-- 顶部控制栏 -->
            <div class="control-bar">
                <div class="left-controls">
                    <div class="layout-menu-container">
                        <button 
                            class="control-btn layout-btn"
                            @click="showLayoutMenu = !showLayoutMenu"
                        >
                            <svg-icon name="九宫格" style="width: 2em; height: 2em;" class="info-icon" />
                        </button>
                        <div 
                            v-if="showLayoutMenu" 
                            class="layout-menu"
                            @click.stop
                        >
                            <div 
                                v-for="option in layoutOptions" 
                                :key="option.id"
                                :class="[
                                    'layout-option',
                                    layoutType === option.id ? 'active' : ''
                                ]"
                                @click="changeLayout(option.id)"
                            >
                                <div class="layout-option-content">     
                                    <!-- <span class="layout-dimensions">
                                        {{ option.cols }}×{{ option.rows }}
                                    </span> -->
                                    <svg-icon :name="option.icon" style="width: 3em; height: 3em;" class="info-icon" />
                                    <span class="layout-name">{{ option.name }}</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <button 
                        class="control-btn fullscreen-btn"
                        @click="goToFullscreen"
                        :disabled="selectedIndex === -1"
                    >
                        <i class="el-icon-full-screen"></i>

                    </button>
                    <button class="control-btn close-volume-btn" @click="muteAllVideos">
                        一键静音
                    </button>
                    <button class="control-btn" @click="unmuteAllVideos">
                        取消静音
                    </button>
                </div>
                <!-- 关闭按钮 -->
                <div class="right-controls">
                    <el-tooltip :open-delay="200" content="关闭" placement="top">
                        <div class="close-btn" @click="toggleClose">
                            <i class="el-icon-circle-close" style="color: white;"></i>
                        </div>
                    </el-tooltip>
                    
                </div>
            </div>
            <!-- 视频网格 -->
            <div 
                class="video-grid"
                :style="getGridStyle()"
            >
                <div 
                    v-for="(camera, index) in getVisibleCameras()" 
                    :key="index" 
                    class="video-card"
                    :class="{ 'selected': selectedIndex === index && layoutType !== '1x1' }"
                    @click="selectedIndex = index"
                    :style="getVideoCardStyle(index)"
                    @mouseenter="showSwitchButtons = true"
                    @mouseleave="showSwitchButtons = false"
                >
                    <!-- 视频标题栏 -->
                    <div class="video-header">
                        <span>{{ camera.location }}</span>
                        <span v-if="layoutType === '1x1'" class="camera-counter">
                            {{ getCurrentCameraNumber() }}/{{ getValidCamerasCount() }}
                        </span>
                    </div>
                    <template v-if="layoutType === '1x1'">
                        <button 
                            class="switch-btn switch-btn-left" 
                            @click.stop="switchCamera('prev')"
                            :disabled="!hasPrevCamera()"
                            v-show="showSwitchButtons"
                        >
                            <i class="el-icon-arrow-left"></i>
                        </button>
                        <button 
                            class="switch-btn switch-btn-right" 
                            @click.stop="switchCamera('next')"
                            :disabled="!hasNextCamera()"
                            v-show="showSwitchButtons"
                        >
                            <i class="el-icon-arrow-right"></i>
                        </button>
                    </template>
                    <!-- 视频画面 -->
                    <div :class="['video-content', { 'error': camera.error, 'empty': camera.isEmpty }]">
                        <!-- 空白通道显示 -->
                        <div v-if="camera.isEmpty" class="empty-channel">
                            <i class="fas fa-video-slash"></i>
                            <span>无视频信号</span>
                        </div>
                        
                        <!-- 加载状态 -->
                        <div v-if="camera.isLoading" class="loading">
                            <div class="loading-spinner"></div>
                            <span class="loading-text">正在刷新视频流...</span>
                        </div>
                        
                        <!-- 错误状态 -->
                        <div v-if="camera.error" class="error-message">
                            <i class="fas fa-exclamation-triangle mr-2"></i>
                            {{ camera.error }}
                        </div>
                        
                        <!-- 视频播放器 -->
                        <M3U8Player
                            v-if="camera.stream && !camera.error && !camera.isEmpty"
                            :url="camera.stream"
                            :muted="false"
                            :show-controls="true"
                            :autoplay="true"
                            :device-id="camera.deviceId"
                            @ready="onPlayerReady(index)"
                            @play="onPlayerPlay(index)"
                            @error="onPlayerError(index, $event)"
                            @pause="onPlayerPause(index)"
                            @toggleControlPanel="toggleControlPanel"
                            @refresh="onPlayerRefresh(index)"
                            ref="videoPlayer"
                        />       
                    </div>
                    <!-- 视频控制栏 - 只在非空白通道显示 -->
                    <!-- <VideoControls /> -->
                </div>
            </div>
            <PtzController :isPtzControlVisible="isPtzControlVisible" :stream="cameras[selectedIndex]"/>
        </div>
        <SingleScreen v-else :camera="cameras[selectedIndex]" @goback="goback"/>    
    </div>
</template>
<script>
import M3U8Player from '@/components/HuaweiVideo/M3U8Player.vue';
import VideoControls from '@/components/HuaweiVideo/VideoControls.vue'
import SingleScreen from '@/components/HuaweiVideo/SingleScreen.vue';
import PtzController from '@/components/HuaweiVideo/PtzController.vue';
import { getChannelList, getLiveStream } from '@/api/video-controller.js'
import deviceChannelService from '@/api/device-channel-service';

export default {
    components: {
        M3U8Player,
        SingleScreen,
        PtzController,
        VideoControls
    },
    data() {
        return {
            selectedIndex: 0, // 添加选中索引，-1表示未选中
            toFullScreen: false,
            onlineCameras: 9,
            totalCameras: 9,
            currentTime: '',
            playerOptions: {
                width: '100%',
                height: '100%',
                autoplay: true,
                controls: false, // 使用自定义控制栏
                muted: false
            },
            layoutType: '3x3', // 默认3x3布局
            layoutOptions: [
                { id: '1x1', name: '01', cols: 1, rows: 1, icon: '1分屏' },
                { id: '2x1', name: '02', cols: 2, rows: 1, icon: '2分屏' },
                { id: '2x2', name: '04', cols: 2, rows: 2, icon: '4分屏' },
                { id: '6grid', name: '06', cols: 3, rows: 3, merge: [[0,0,2,2]], icon: '6分屏' },
                { id: '7grid', name: '07', cols: 4, rows: 4, merge: [[0,0,2,2],[0,1,2,2],[1,0,2,2]], icon: '7分屏' },
                { id: '8grid', name: '08', cols: 4, rows: 4, merge: [[0,0,3,3]], icon: '8分屏' },
                { id: '3x3', name: '09', cols: 3, rows: 3, icon: '9分屏' }
            ],
            showLayoutMenu: false,
            cameras: [],
            isPtzControlVisible: false,
            showSwitchButtons: false
        };
    },
    computed: {
        channelName() {
            return this.$store.getters['getCurrentChannel'] || '';
        },
        stationId() {
            return this.$route.query.stationId;
        }
    },
    async created() {
        this.updateTime();
        setInterval(this.updateTime, 1000);
        try {
            // 获取通道列表
            const devices = await this.getDevices(this.stationId);
            // 为每个通道获取直播流地址
            const cameras = await Promise.all(devices.map(async (device, index) => {
                try {
                    const liveResponse = await getLiveStream({channels: [{
                        device_id: device.thirdPartyId,
                        channel_id: device.thirdPartyId,
                        live_protocol: "HTTPS_HLS",
                        stream_type: "PRIMARY_STREAM"
                        }]}
                    );
                    
                    return {
                        location: device.thirdPartyName || `摄像头 ${index + 1}`,
                        stream: liveResponse?.live_connections[0]?.cloud_trans_connections?.live_url,
                        deviceId: device.thirdPartyId,
                        channelId: device.thirdPartyId,
                        isPlaying: false,
                        error: null,
                        retryCount: 0,
                        isLoading: false
                    };
                } catch (error) {
                    console.error(`获取通道 ${device.thirdPartyId} 直播流失败:`, error);
                    return {
                        location: device.thirdPartyName || `摄像头 ${index + 1}`,
                        stream: '',
                        deviceId: device.thirdPartyId,
                        channelId: device.thirdPartyId,
                        isPlaying: false,
                        error: '获取直播流失败'
                    };
                }
            }));
            
            this.cameras = cameras;
        } catch (error) {
            console.error('获取通道列表失败:', error);
            this.cameras = this.cameras.map(camera => ({
                ...camera,
                error: '获取通道列表失败'
            }));
        }
    },
    methods: {
        goback() {
            this.toFullScreen = false
        },
        toggleClose() {
            this.$router.go(-1);
        },
        toggleControlPanel() {
            this.isPtzControlVisible = !this.isPtzControlVisible;
        },
        async getDevices(id) {
            try {
                // const devices = await deviceChannelService.getDevicesByOrgName(orgName);
                const devices = await deviceChannelService.getDevicesByStationId({stationIds: [id]});
                console.log('获取到的通道列表：', devices);
                return [
                {
                    id: "1932304215972118528--__hw8pZmKQpL6F8rl2lUa",
                    stationId: "3fAR4jRBL04DQoeW4Wd--__Pg1xGkcJskeVnxOMxSf",
                    thirdPartyId: "44000000001320000099",
                    thirdPartyName: "富春"
                }
                ];
            } catch (error) {
                console.error('获取通道列表失败：', error);
            }
        },

        updateTime() {
            const now = new Date();
            const year = now.getFullYear();
            const month = String(now.getMonth() + 1).padStart(2, '0');
            const day = String(now.getDate()).padStart(2, '0');
            const hours = String(now.getHours()).padStart(2, '0');
            const minutes = String(now.getMinutes()).padStart(2, '0');
            const seconds = String(now.getSeconds()).padStart(2, '0');
            this.currentTime = `${year}/${month}/${day} ${hours}:${minutes}:${seconds}`;
        },
        
        // 播放器就绪事件处理
        onPlayerReady(index) {
            console.log(`播放器 ${index} 就绪`);
        },

        // 播放状态改变事件处理
        onPlayerPlay(index) {
            this.cameras[index].isPlaying = true;
            this.cameras[index].error = null;
            this.cameras[index].retryCount = 0; // 重置重试计数
            console.log(`播放器 ${index} 开始播放`);
        },

        // 暂停事件处理
        onPlayerPause(index) {
            this.cameras[index].isPlaying = false;
            console.log(`播放器 ${index} 已暂停`);
        },
        onPlayerRefresh(index) {
            console.log(`播放器 ${index} 刷新`);
        },
        // 获取新的流地址
        async getNewStreamUrl(deviceId, channelId, retryCount = 0) {
            try {
                const liveResponse = await getLiveStream({
                    channels: [{
                        device_id: deviceId,
                        channel_id: channelId,
                        live_protocol: "http_flv",
                        stream_type: "PRIMARY_STREAM"
                    }]
                });
                return liveResponse.channels[0].live_url;
            } catch (error) {
                console.error('获取新流地址失败:', error);
                throw error;
            }
        },

        // 错误处理
        async onPlayerError(index, event) {
            console.error(`播放器 ${index} 错误:`, event);
            this.cameras[index].isPlaying = false;

            // 获取当前摄像头信息
            const camera = this.cameras[index];
            if (!camera || !camera.deviceId || !camera.channelId) {
                this.cameras[index].error = '摄像头信息无效';
                return;
            }

            // 检查重试次数
            camera.retryCount = (camera.retryCount || 0) + 1;
            if (camera.retryCount > 3) {
                this.cameras[index].error = '重试次数过多，请刷新页面重试';
                return;
            }

            try {
                // 获取新的流地址
                const newStreamUrl = await this.getNewStreamUrl(
                    camera.deviceId,
                    camera.channelId,
                    camera.retryCount
                );

                // 更新流地址
                this.cameras[index].stream = newStreamUrl;
                this.cameras[index].error = null;

                // 重置播放器
                this.$nextTick(() => {
                    const player = this.$refs.videoPlayer[index];
                    if (player) {
                        player.play().catch(error => {
                            console.error(`重试播放失败:`, error);
                            this.cameras[index].error = '重试播放失败，请刷新页面';
                        });
                    }
                });
            } catch (error) {
                this.cameras[index].error = '获取新流地址失败，请刷新页面重试';
            }
        },

        // 切换播放/暂停
        togglePlay(index) {
            const player = this.$refs.videoPlayer[index];
            if (!player) return;

            try {
                if (this.cameras[index].isPlaying) {
                    player.pause();
                } else {
                    player.play().catch(error => {
                        console.error(`播放器 ${index} 播放失败:`, error);
                        this.cameras[index].error = '播放失败，请重试';
                    });
                }
            } catch (error) {
                console.error(`播放器 ${index} 操作失败:`, error);
                this.cameras[index].error = '操作失败，请重试';
            }
        },

        // 切换全屏
        toggleFullscreen(index) {
            const videoContainer = this.$refs.videoPlayer[index].$el;
            if (!videoContainer) return;

            if (document.fullscreenElement) {
                document.exitFullscreen();
            } else {
                videoContainer.requestFullscreen();
            }
        },

        // 截图功能
        takeScreenshot(index) {
            const player = this.$refs.videoPlayer[index];
            if (!player) return;

            const screenshot = player.screenshot();
            if (screenshot) {
                // 创建下载链接
                const link = document.createElement('a');
                link.href = screenshot;
                link.download = `camera_${this.cameras[index].location}_${new Date().getTime()}.jpg`;
                link.click();
            }
        },

        // 手动刷新视频流
        async refreshStream(index) {
            const camera = this.cameras[index];
            if (!camera || !camera.deviceId || !camera.channelId) {
                this.$message.error('摄像头信息无效');
                return;
            }

            // 设置加载状态
            this.cameras[index].isLoading = true;
            this.cameras[index].error = null;
            this.cameras[index].retryCount = 0;

            try {
                // 获取新的流地址
                const newStreamUrl = await this.getNewStreamUrl(
                    camera.deviceId,
                    camera.channelId,
                    0
                );

                // 更新流地址
                this.cameras[index].stream = newStreamUrl;

                // 重置播放器
                this.$nextTick(() => {
                    const player = this.$refs.videoPlayer[index];
                    if (player) {
                        player.play().catch(error => {
                            console.error(`刷新播放失败:`, error);
                            this.cameras[index].error = '刷新播放失败，请重试';
                        });
                    }
                });
            } catch (error) {
                console.error('刷新流失败:', error);
                this.cameras[index].error = '刷新失败，请重试';
            } finally {
                this.cameras[index].isLoading = false;
            }
        },

        // 打开设置
        openSettings(index) {
            // 实现设置面板逻辑
            console.log(`打开摄像头 ${index} 的设置`);
        },
        
        // 切换布局
        changeLayout(layoutId) {
            this.layoutType = layoutId;
            this.showLayoutMenu = false;
        },
        
        // 获取网格布局样式
        getGridStyle() {
            const option = this.layoutOptions.find(opt => opt.id === this.layoutType);
            if (!option) return {};
            
            const cols = option.cols;
            const rows = option.rows;
            
            return {
                'grid-template-columns': `repeat(${cols}, 1fr)`,
                'grid-template-rows': `repeat(${rows}, 1fr)`
            };
        },
        
        // 获取当前布局应该显示的摄像头
        getVisibleCameras() {
            const option = this.layoutOptions.find(opt => opt.id === this.layoutType);
            if (!option) return this.cameras.slice(0, 1); // 默认显示第一个摄像头
            
            // 1x1布局特殊处理
            if (option.id === '1x1') {
                // 如果有选中的摄像头且不是空通道，则显示选中的摄像头
                if (this.selectedIndex !== -1 && !this.cameras[this.selectedIndex]?.isEmpty) {
                    return [this.cameras[this.selectedIndex]];
                }
                // 如果没有选中的摄像头或选中的是空通道，显示第一个非空通道
                const firstValidCamera = this.cameras.find(camera => !camera.isEmpty);
                if (firstValidCamera) {
                    return [firstValidCamera];
                }
                // 如果没有有效的摄像头，显示提示
                return [{
                    location: '无可用通道',
                    stream: null,
                    deviceId: null,
                    isPlaying: false,
                    error: null,
                    isEmpty: true
                }];
            }
            
            // 计算当前布局需要的摄像头数量
            let count = option.cols * option.rows;
            if (option.merge) {
                // 如果有合并单元格，需要调整数量
                for (const merge of option.merge) {
                    const [startRow, startCol, rowSpan, colSpan] = merge;
                    count -= (rowSpan * colSpan - 1);
                }
            }
            
            // 获取实际的摄像头列表
            const visibleCameras = this.cameras.slice(0, Math.min(count, this.cameras.length));
            
            // 如果实际摄像头数量小于需要的数量，补充空白通道
            while (visibleCameras.length < count) {
                visibleCameras.push({
                    location: `空白通道 ${visibleCameras.length + 1}`,
                    stream: null,
                    deviceId: null,
                    isPlaying: false,
                    error: null,
                    isEmpty: true // 标记为空白通道
                });
            }
            
            return visibleCameras;
        },
        
        // 获取视频卡片样式（处理合并单元格）
        getVideoCardStyle(index) {
            const option = this.layoutOptions.find(opt => opt.id === this.layoutType);
            if (!option || !option.merge) return {};
            
            for (const merge of option.merge) {
                const [startRow, startCol, rowSpan, colSpan] = merge;
                if (index === startRow * option.cols + startCol) {
                    return {
                        'grid-row': `span ${rowSpan}`,
                        'grid-column': `span ${colSpan}`
                    };
                }
            }
            
            return {};
        },

        // 跳转到全屏页面
        goToFullscreen() {
            if (this.selectedIndex === -1) return;
            
            const selectedCamera = this.cameras[this.selectedIndex];
            this.toFullScreen = true;
            // this.$router.push({
            //     path: '/singleVideo',
            //     query: {
            //         deviceId: selectedCamera?.deviceId,
            //         channelId: selectedCamera?.channelId
            //     }
            // });
        },

        // 切换摄像头
        switchCamera(direction) {
            const validCameras = this.cameras.filter(camera => !camera.isEmpty);
            if (validCameras.length === 0) return;

            const currentIndex = validCameras.findIndex(
                camera => camera.deviceId === this.cameras[this.selectedIndex]?.deviceId
            );

            let newIndex;
            if (direction === 'next' && currentIndex < validCameras.length - 1) {
                newIndex = currentIndex + 1;
            } else if (direction === 'prev' && currentIndex > 0) {
                newIndex = currentIndex - 1;
            } else {
                return; // 如果已经是第一个或最后一个，不进行切换
            }

            // 找到新选中摄像头在原数组中的索引
            const originalIndex = this.cameras.findIndex(
                camera => camera.deviceId === validCameras[newIndex].deviceId
            );
            
            // 重置错误状态和重试计数
            if (this.cameras[originalIndex]) {
                this.cameras[originalIndex].error = null;
                this.cameras[originalIndex].retryCount = 0;
            }
            
            this.selectedIndex = originalIndex;
        },

        // 检查是否有上一个摄像头
        hasPrevCamera() {
            const validCameras = this.cameras.filter(camera => !camera.isEmpty);
            const currentIndex = validCameras.findIndex(
                camera => camera.deviceId === this.cameras[this.selectedIndex]?.deviceId
            );
            return currentIndex > 0;
        },

        // 检查是否有下一个摄像头
        hasNextCamera() {
            const validCameras = this.cameras.filter(camera => !camera.isEmpty);
            const currentIndex = validCameras.findIndex(
                camera => camera.deviceId === this.cameras[this.selectedIndex]?.deviceId
            );
            return currentIndex < validCameras.length - 1;
        },

        // 获取当前摄像头序号
        getCurrentCameraNumber() {
            const validCameras = this.cameras.filter(camera => !camera.isEmpty);
            const currentIndex = validCameras.findIndex(
                camera => camera.deviceId === this.cameras[this.selectedIndex]?.deviceId
            );
            return currentIndex + 1;
        },

        // 获取有效摄像头总数
        getValidCamerasCount() {
            return this.cameras.filter(camera => !camera.isEmpty).length;
        },
        
        // 一键静音所有视频
        muteAllVideos() {
            if (!this.$refs.videoPlayer) return;
            
            // 遍历所有视频播放器组件
            this.$refs.videoPlayer.forEach((player, index) => {
                if (player && typeof player.setMuted === 'function') {
                    player.setMuted(true);
                    // 更新摄像头状态
                    if (this.cameras[index]) {
                        this.cameras[index].isMuted = true;
                    }
                }
            });
            
            this.$message({
                message: '已将所有视频静音',
                type: 'success',
                duration: 2000
            });
        },
        
        // 取消所有视频的静音
        unmuteAllVideos() {
            if (!this.$refs.videoPlayer) return;
            
            // 遍历所有视频播放器组件
            this.$refs.videoPlayer.forEach((player, index) => {
                if (player && typeof player.setMuted === 'function') {
                    player.setMuted(false);
                    // 更新摄像头状态
                    if (this.cameras[index]) {
                        this.cameras[index].isMuted = false;
                    }
                }
            });
            
            this.$message({
                message: '已取消所有视频的静音',
                type: 'success',
                duration: 2000
            });
        }
    }
};
</script>
<style scoped>
.monitor-page {
    min-height: 100vh;
    background-color: #f3f4f6;
}

.container {
    max-width: 100vw;
    margin: 0 auto;
    padding-top: 10px;
    background-color: #0c4892;
}

.control-bar {
    display: flex;
    align-items: center;
    justify-content: space-between;
    /* margin-bottom: 12px; */
    padding: 0 16px;
}

.left-controls {
    display: flex;
    align-items: center;
}

.left-controls > * {
    margin-right: 16px;
}

.layout-menu-container {
    position: relative;
}

.control-btn {
    height: 40px;
    display: flex;
    align-items: center;
    padding: 4px 8px;
    background-color: #25b3eb;
    color: white;
    border: none;
    border-radius: 8px;
    cursor: pointer;
    font-size: 20px;
    transition: background-color 0.2s ease;
}
.layout-btn {
    background-color: #91a6af;
}
.fullscreen-btn {
    background-color: #10b981;
    font-size: 32px;
    width: 50px;
}
.fullscreen-btn:hover {
    background-color: #059669;
}
.fullscreen-btn:disabled {
    background-color: #9ca3af;
    cursor: not-allowed;
}
.close-volume-btn {
    background-color: #e68c18;
}
.control-btn:hover {
    background-color: #1d4ed8;
}

.control-btn i {
    margin-right: 8px;
}

.layout-menu {
    position: absolute;
    left: 0;
    top: 100%;
    margin-top: 8px;
    background: white;
    border-radius: 8px;
    box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
    z-index: 100;
    min-width: 150px;
    overflow: hidden;
    display: grid;
    grid-template-columns: repeat(3, 1fr);
    grid-template-rows: repeat(3, 1fr);
    grid-auto-flow: dense;
    align-items: stretch;
    justify-items: stretch;

}

.layout-option {
    padding: 16px 16px;
    cursor: pointer;
    transition: all 0.2s ease;
    font-size: 14px;
    color: #333;
}

.layout-option:hover {
    background: #f0f9f9;
    color: #6bdfdf;
}

.layout-option.active {
    background: #6bdfdf;
    color: white;
}

.layout-option-content {
    display: flex;
    align-items: center;
    justify-content: space-between;
}
.layout-name {
    width: 40px;
    font-size: 24px;
    padding-left: 8px;
}
.layout-dimensions {
    font-size: 12px;
    color: #666;
}

.layout-option.active .layout-dimensions {
    color: rgba(255,255,255,0.8);
}

.video-grid {
    display: grid;
    gap: 8px;
    height: calc(100vh - 135px);
    overflow-y: auto;
    padding: 8px;
    transition: all 0.3s ease;
    grid-auto-flow: dense;
    align-items: stretch;
    justify-items: stretch;
}

.video-card {
    min-width: 0;
    min-height: 0;
}

/* 默认3x3布局 */
.video-grid[style*="3x3"] {
    grid-template-columns: repeat(3, 1fr);
    grid-template-rows: repeat(3, 1fr);
}

/* 1x1单通道布局 */
.video-grid[style*="1x1"] {
    grid-template-columns: 1fr;
    grid-template-rows: 1fr;
}

/* 2x1两通道布局 */
.video-grid[style*="2x1"] {
    grid-template-columns: repeat(2, 1fr);
    grid-template-rows: 1fr;
}

/* 2x2四通道布局 */
.video-grid[style*="2x2"] {
    grid-template-columns: repeat(2, 1fr);
    grid-template-rows: repeat(2, 1fr);
}

/* 六通道特殊布局 */
.video-grid[style*="6grid"] {
    grid-template-columns: repeat(3, 1fr);
    grid-template-rows: repeat(3, 1fr);
}

/* 七通道特殊布局 */
.video-grid[style*="7grid"] {
    grid-template-columns: repeat(4, 1fr);
    grid-template-rows: repeat(4, 1fr);
}

/* 八通道特殊布局 */
.video-grid[style*="8grid"] {
    grid-template-columns: repeat(4, 1fr);
    grid-template-rows: repeat(4, 1fr);
}

.video-card {
    background-color: rgb(0, 0, 0);
    border-radius: 8px;
    overflow: hidden;
    box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    border: #6bdfdf solid 5px;
    max-width: 100%;
    margin: 0;
    width: 100%;
    transition: all 0.3s ease;
    position: relative;
    aspect-ratio: 16/9;
}

.video-card.selected {
    border: 5px solid #78ed19;
    box-shadow: 0 0 0 3px rgba(24, 144, 255, 0.3);
    /* transform: scale(0.98); */
    transition: all 0.2s ease;
    z-index: 10;
}

/* 合并单元格的卡片样式 */
.video-card[style*="grid-row: span 2"],
.video-card[style*="grid-column: span 2"] {
    aspect-ratio: unset;
}

.video-card[style*="grid-row: span 3"],
.video-card[style*="grid-column: span 3"] {
    aspect-ratio: unset;
}

.video-card[style*="grid-row: span 4"],
.video-card[style*="grid-column: span 4"] {
    aspect-ratio: unset;
}

.video-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 8px 16px;
    background-color: #00000000;
    color: white;
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    z-index: 10;
    font-size: 16px;
}

.video-header .title {
    font-weight: bold;
    margin: 0;
}

.video-header .actions {
    display: flex;
    align-items: center;
}

.video-header .actions button {
}

.video-content {
    position: relative;
    aspect-ratio: 16/9;
    background-color: black;
    display: flex;
    flex-direction: column;
    height: 100%;
    width: 100%;
}

.video-content img {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    object-fit: contain;
}

.video-controls {
    position: absolute;
    bottom: 0;
    left: 0;
    right: 0;
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 8px 16px;
    /* background: linear-gradient(to top, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0) 100%); */
    z-index: 20;
    opacity: 0;
    transition: opacity 0.3s ease;
}

.video-card:hover .video-controls {
    opacity: 1;
}

.left-controls,
.right-controls {
    display: flex;
    align-items: center;
    gap: 12px;
}

.control-icon-btn {
    color: white;
    background: none;
    border: none;
    cursor: pointer;
    padding: 4px;
}

.control-icon-btn:hover {
    color: #60a5fa;
}

/* 视频播放器样式 */
.video-content :deep(.huawei-video-player) {
    width: 100%;
    height: 100%;
}

.video-content :deep(.video-container) {
    width: 100%;
    height: 100%;
}

/* 错误状态样式 */
.video-content.error {
    display: flex;
    align-items: center;
    justify-content: center;
    color: #ef4444;
    font-size: 14px;
    padding: 20px;
    text-align: center;
}

.video-content.empty {
    display: flex;
    align-items: center;
    justify-content: center;
    background-color: #1a1a1a;
}

.empty-channel {
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    color: #666;
    gap: 12px;
}

.empty-channel i {
    font-size: 32px;
}

.empty-channel span {
    font-size: 14px;
}

.error-message{
    color: #ef4444;
    font-size: 14px;
    padding: 20px;
    text-align: center;
}

/* 左右切换按钮样式 */
.switch-btn {
    position: absolute;
    top: 50%;
    transform: translateY(-50%);
    background-color: rgba(0, 0, 0, 0.5);
    color: white;
    border: none;
    border-radius: 50%;
    width: 40px;
    height: 40px;
    display: flex;
    align-items: center;
    justify-content: center;
    cursor: pointer;
    transition: all 0.3s ease;
    z-index: 10;
}

.switch-btn:hover:not(:disabled) {
    background-color: rgba(0, 0, 0, 0.8);
}

.switch-btn:disabled {
    background-color: rgba(0, 0, 0, 0.2);
    cursor: not-allowed;
    color: rgba(255, 255, 255, 0.3);
}

.switch-btn-left {
    left: 16px;
}

.switch-btn-right {
    right: 16px;
}

.switch-btn i {
    font-size: 24px;
}

/* 摄像头计数器样式 */
.camera-counter {
    background-color: rgba(0, 0, 0, 0.6);
    padding: 4px 8px;
    border-radius: 4px;
    font-size: 12px;
    color: white;
}
/* 加载状态样式 */
.video-content.loading {
    display: flex;
    align-items: center;
    justify-content: center;
}

.loading {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    background: rgba(0, 0, 0, 0.7);
    z-index: 30;
}

.loading-spinner {
    width: 40px;
    height: 40px;
    border: 4px solid rgba(255, 255, 255, 0.3);
    border-radius: 50%;
    border-top-color: #fff;
    animation: spin 1s ease-in-out infinite;
    margin-bottom: 16px;
}

.loading-text {
    color: white;
    font-size: 14px;
}

@keyframes spin {
    to { transform: rotate(360deg); }
}

/* 刷新按钮旋转动画 */
.control-icon-btn i.fa-sync-alt {
    transition: transform 0.3s ease;
}

.control-icon-btn:active i.fa-sync-alt {
    transform: rotate(180deg);
}

/* 禁用状态 */
.control-icon-btn:disabled {
    opacity: 0.5;
    cursor: not-allowed;
}

/* 刷新中状态 */
.control-icon-btn.refreshing i.fa-sync-alt {
    animation: spin 1s linear infinite;
}

::v-deep(.controls) {
    bottom: -5px;
    opacity: 1;
}
</style>